"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRules = void 0;
var altAttribute_1 = require("./parsers/altAttribute");
var camelCaseString_1 = require("./parsers/camelCaseString");
var emailPattern_1 = require("./parsers/emailPattern");
var escapeSequence_1 = require("./parsers/escapeSequence");
var filePattern_1 = require("./parsers/filePattern");
var fluentFunction_1 = require("./parsers/fluentFunction");
var fluentParametrizedTerm_1 = require("./parsers/fluentParametrizedTerm");
var fluentString_1 = require("./parsers/fluentString");
var fluentTerm_1 = require("./parsers/fluentTerm");
var javaFormattingVariable_1 = require("./parsers/javaFormattingVariable");
var jsonPlaceholder_1 = require("./parsers/jsonPlaceholder");
var leadingSpace_1 = require("./parsers/leadingSpace");
var multipleSpaces_1 = require("./parsers/multipleSpaces");
var narrowNonBreakingSpace_1 = require("./parsers/narrowNonBreakingSpace");
var newlineCharacter_1 = require("./parsers/newlineCharacter");
var newlineEscape_1 = require("./parsers/newlineEscape");
var nonBreakingSpace_1 = require("./parsers/nonBreakingSpace");
var nsisVariable_1 = require("./parsers/nsisVariable");
var numberString_1 = require("./parsers/numberString");
var optionPattern_1 = require("./parsers/optionPattern");
var punctuation_1 = require("./parsers/punctuation");
var pythonFormatNamedString_1 = require("./parsers/pythonFormatNamedString");
var pythonFormatString_1 = require("./parsers/pythonFormatString");
var pythonFormattingVariable_1 = require("./parsers/pythonFormattingVariable");
var qtFormatting_1 = require("./parsers/qtFormatting");
var shortCapitalNumberString_1 = require("./parsers/shortCapitalNumberString");
var stringFormattingVariable_1 = require("./parsers/stringFormattingVariable");
var tabCharacter_1 = require("./parsers/tabCharacter");
var thinSpace_1 = require("./parsers/thinSpace");
var unusualSpace_1 = require("./parsers/unusualSpace");
var uriPattern_1 = require("./parsers/uriPattern");
var xmlEntity_1 = require("./parsers/xmlEntity");
var xmlTag_1 = require("./parsers/xmlTag");
/**
 * Build an array of parser rules from those included in the package:
 * an extensive set suitable for highlighting localizable text.
 * Originally built for and used by [Pontoon](https://pontoon.mozilla.org/).
 *
 * All options default to `false`:
 * - `fluent`: Include rules for [Project Fluent](https://projectfluent.org/) syntax.
 * - `leadingSpaces`: Include rules for leading spaces.
 *
 * For a fully custom set of rules,
 * explore and import the individual rules available under `react-content-marker/lib/parsers/`
 * and build your own rule array.
 */
function getRules(opt) {
    // Note: the order of these MATTERS!
    var rules = [
        newlineEscape_1.newlineEscape,
        newlineCharacter_1.newlineCharacter,
        tabCharacter_1.tabCharacter,
        escapeSequence_1.escapeSequence,
    ];
    // The spaces rule can match '\n  ' and mask the newline,
    // so they have to come later.
    if (opt === null || opt === void 0 ? void 0 : opt.leadingSpaces) {
        rules.push(leadingSpace_1.leadingSpace, unusualSpace_1.unusualSpace);
    }
    rules.push(nonBreakingSpace_1.nonBreakingSpace, narrowNonBreakingSpace_1.narrowNonBreakingSpace, thinSpace_1.thinSpace, multipleSpaces_1.multipleSpaces);
    if (opt === null || opt === void 0 ? void 0 : opt.fluent) {
        rules.push(fluentString_1.fluentString, fluentParametrizedTerm_1.fluentParametrizedTerm, fluentTerm_1.fluentTerm, fluentFunction_1.fluentFunction);
    }
    rules.push(
    // The XML rules must be marked before variables
    // to avoid marking variables, but leaving out tags.
    // See https://bugzilla.mozilla.org/show_bug.cgi?id=1334926
    xmlTag_1.xmlTag, altAttribute_1.altAttribute, xmlEntity_1.xmlEntity, pythonFormatNamedString_1.pythonFormatNamedString, pythonFormatString_1.pythonFormatString, pythonFormattingVariable_1.pythonFormattingVariable, javaFormattingVariable_1.javaFormattingVariable, stringFormattingVariable_1.stringFormattingVariable, 
    // JSON Placeholder parser Must come before NSIS Variable parser,
    // otherwise JSON Placeholders are marked up without the trailing $
    jsonPlaceholder_1.jsonPlaceholder, nsisVariable_1.nsisVariable, 
    // The Qt variables can consume the %1 in %1$s which will mask a printf
    // placeable, so it has to come later.
    qtFormatting_1.qtFormatting, uriPattern_1.uriPattern, filePattern_1.filePattern, emailPattern_1.emailPattern, shortCapitalNumberString_1.shortCapitalNumberString, camelCaseString_1.camelCaseString, optionPattern_1.optionPattern, punctuation_1.punctuation, numberString_1.numberString);
    return rules;
}
exports.getRules = getRules;
