"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mark = void 0;
var markRegExp_1 = require("./markRegExp");
var markTerm_1 = require("./markTerm");
/**
 * Replaces matching patterns in a string with markers.
 *
 * @param content The content to parse and mark.
 *
 * @param rule The pattern to search and replace in the
 * content.
 *
 * @param tag A function that takes the match string and must return
 * a React element. The value returned by that function will
 * replace the term in the output.
 *
 * @param matchIndex The index of the match to use when marking with
 * a RegExp. If not provided, will use the last non-null match available.
 *
 * @returns An array of strings and components,
 * similar to the original content but where each matching pattern has been
 * replaced by a marking component.
 */
function mark(content, rule, tag, matchIndex) {
    if (!Array.isArray(content)) {
        content = [content];
    }
    var output = [];
    for (var _i = 0, content_1 = content; _i < content_1.length; _i++) {
        var part = content_1[_i];
        if (typeof part === 'string') {
            var marked = void 0;
            if (rule instanceof RegExp) {
                marked = (0, markRegExp_1.markRegExp)(part, rule, tag, matchIndex);
            }
            else if (typeof rule === 'string') {
                marked = (0, markTerm_1.markTerm)(part, rule, tag);
            }
            else {
                throw Error("Unsupported rule type for rule ".concat(rule, "."));
            }
            output.push.apply(output, marked);
        }
        else {
            output.push(part);
        }
    }
    return output;
}
exports.mark = mark;
