"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.markTerm = void 0;
/**
 * Replaces matching terms in a string with markers.
 *
 * @param content The content to parse and mark.
 *
 * @param term The term to search and replace in the content. Case sensitive.
 *
 * @param tag A function that takes the matched term and must return
 * a React component or a string. The value returned by that function will
 * replace the term in the output.
 *
 * @returns An array of strings and components,
 * similar to the original content but where each matching pattern has been
 * replaced by a marking component.
 */
function markTerm(content, term, tag) {
    var parts = content.split(term);
    var output = [];
    if (parts[0]) {
        output.push(parts[0]);
    }
    for (var i = 1; i < parts.length; i++) {
        output.push(tag(term));
        if (parts[i]) {
            output.push(parts[i]);
        }
    }
    return output;
}
exports.markTerm = markTerm;
