/// <reference types="react" />
/**
 * Marks Java MessageFormat formatting variables.
 *
 * Implemented according to the Java MessageFormat documentation —
 * https://docs.oracle.com/javase/7/docs/api/java/text/MessageFormat.html
 *
 * Information about custom formats:
 *   - number: DecimalFormat — https://docs.oracle.com/javase/7/docs/api/java/text/DecimalFormat.html
 *   - date/time: SimpleDateFormat — https://docs.oracle.com/javase/7/docs/api/java/text/SimpleDateFormat.html
 *   - choice: ChoiceFormat — https://docs.oracle.com/javase/7/docs/api/java/text/ChoiceFormat.html
 *
 * Example matches:
 *
 *   {2}
 *   {1,date}
 *   {0,number,integer}
 *
 * Source:
 * https://github.com/translate/translate/blob/2.3.1/translate/storage/placeables/general.py#L127
 */
export declare const javaFormattingVariable: {
    rule: RegExp;
    matchIndex: number;
    tag: (x: string) => JSX.Element;
};
