"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.javaFormattingVariable = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
/**
 * Marks Java MessageFormat formatting variables.
 *
 * Implemented according to the Java MessageFormat documentation —
 * https://docs.oracle.com/javase/7/docs/api/java/text/MessageFormat.html
 *
 * Information about custom formats:
 *   - number: DecimalFormat — https://docs.oracle.com/javase/7/docs/api/java/text/DecimalFormat.html
 *   - date/time: SimpleDateFormat — https://docs.oracle.com/javase/7/docs/api/java/text/SimpleDateFormat.html
 *   - choice: ChoiceFormat — https://docs.oracle.com/javase/7/docs/api/java/text/ChoiceFormat.html
 *
 * Example matches:
 *
 *   {2}
 *   {1,date}
 *   {0,number,integer}
 *
 * Source:
 * https://github.com/translate/translate/blob/2.3.1/translate/storage/placeables/general.py#L127
 */
exports.javaFormattingVariable = {
    rule: /({[0-9]+(,\s*(number(,\s*(integer|currency|percent|[-0#.,E;%\u2030\u00a4']+)?)?|(date|time)(,\s*(short|medium|long|full|.+?))?|choice,([^{]+({.+})?)+)?)?})/,
    matchIndex: 0,
    tag: function (x) { return ((0, jsx_runtime_1.jsx)("mark", __assign({ "data-mark": "javaFormattingVariable", title: "Java Message formatting variable" }, { children: x }))); },
};
