"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.qtFormatting = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
/**
 * Marks Qt string formatting variables.
 *
 * Implemented following Qt documentation on QString::arg:
 * https://doc.qt.io/qt-5/qstring.html#arg
 * The placeables are refered to as 'place markers'.
 *
 * Notes:
 *   - Place markers can be reordered
 *   - Place markers may be repeated
 *   - 'L' use a localised representation e.g. in a number
 *   - %% some in the wild to escape real %, not documented (not in regex)
 *
 * Example matches:
 *
 *   %1
 *   %99
 *   %L1
 *
 * Source:
 * https://github.com/translate/translate/blob/2.3.1/translate/storage/placeables/general.py#L80
 */
exports.qtFormatting = {
    rule: /(%L?[1-9]\d{0,1}(?=([^\d]|$)))/,
    matchIndex: 0,
    tag: function (x) { return ((0, jsx_runtime_1.jsx)("mark", __assign({ "data-mark": "qtFormatting", title: "Qt string formatting variable" }, { children: x }))); },
};
